
## BioSAK (A Swiss-Army-Knife for Bioinformaticians)

[![pypi licence ](https://img.shields.io/pypi/l/BioSAK.svg)](https://opensource.org/licenses/gpl-3.0.html)
[![pypi version ](https://img.shields.io/pypi/v/BioSAK.svg)](https://pypi.python.org/pypi/BioSAK) 
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4070001.svg)](https://doi.org/10.5281/zenodo.4070001)


Contact
---

Shan Zhang<sup>1,2</sup> and Weizhi Song<sup>1,2</sup>

<sup>1</sup> Center for Marine Science & Innovation, University of New South Wales, Sydney, Australia

<sup>2</sup> Department of Ocean Science, Hong Kong University of Science and Technology, Hong Kong

E-mail: shanzhang@ust.hk and songwz03@gmail.com


Installation
---

+ BioSAK has been tested on Linux/Mac, but **NOT** yet on Windows.


+ BioSAK is implemented in python3, you can

  + install it with `pip3 install BioSAK`
  
  + upgrade it with `pip3 install --upgrade BioSAK`


+ If you are an UNSW [Katana](https://research.unsw.edu.au/katana) user, [this](doc/katana.md) might be helpful.


BioSAK modules
---

+ Type `BioSAK -h` to see a [full list of modules](doc/full_list_modules.md) available in BioSAK.


+ A changelog is [here](BioSAK/VERSION).


 Getting help
---

+ You can get example commands for most of the modules by typing, for example, `BioSAK iTOL -h`.


+ Please refer to the [documentation](doc/Index.md) page for help (in preparation, very messy).


[//]: # (+ **中文版**帮助文件[在此]&#40;doc/Index_cn.md&#41;.)


+ A license statement is [here](LICENSE).
